@@ -26,6 +26,9 @@ typedef struct
   GQuark copy_tag;
 } CopyMetaData;
 
+GQuark rtp_quark_meta_tag_video;
+GQuark rtp_quark_meta_tag_audio;
+
 static gboolean
 foreach_metadata_copy (GstBuffer * inbuf, GstMeta ** meta, gpointer user_data)
 {
@@ -36,8 +39,9 @@ foreach_metadata_copy (GstBuffer * inbuf, GstMeta ** meta, gpointer user_data)
   const GstMetaInfo *info = (*meta)->info;
   const gchar *const *tags = gst_meta_api_type_get_tags (info->api);
 
-  if (!tags || (copy_tag != 0 && g_strv_length ((gchar **) tags) == 1
-          && gst_meta_api_type_has_tag (info->api, copy_tag))) {
+  if (info->transform_func && (!tags || (copy_tag != 0
+              && g_strv_length ((gchar **) tags) == 1
+              && gst_meta_api_type_has_tag (info->api, copy_tag)))) {
     GstMetaTransformCopy copy_data = { FALSE, 0, -1 };
     GST_DEBUG_OBJECT (element, "copy metadata %s", g_type_name (info->api));
     /* simply copy then */
@@ -61,6 +65,20 @@ gst_rtp_copy_meta (GstElement * element, GstBuffer * outbuf, GstBuffer * inbuf,
   gst_buffer_foreach_meta (inbuf, foreach_metadata_copy, &data);
 }
 
+void
+gst_rtp_copy_video_meta (gpointer element, GstBuffer * outbuf,
+    GstBuffer * inbuf)
+{
+  gst_rtp_copy_meta (element, outbuf, inbuf, rtp_quark_meta_tag_video);
+}
+
+void
+gst_rtp_copy_audio_meta (gpointer element, GstBuffer * outbuf,
+    GstBuffer * inbuf)
+{
+  gst_rtp_copy_meta (element, outbuf, inbuf, rtp_quark_meta_tag_audio);
+}
+
 typedef struct
 {
   GstElement *element;
@@ -95,3 +113,40 @@ gst_rtp_drop_meta (GstElement * element, GstBuffer * buf, GQuark keep_tag)
 
   gst_buffer_foreach_meta (buf, foreach_metadata_drop, &data);
 }
+
+void
+gst_rtp_drop_non_audio_meta (gpointer element, GstBuffer * buf)
+{
+  gst_rtp_drop_meta (element, buf, rtp_quark_meta_tag_audio);
+}
+
+void
+gst_rtp_drop_non_video_meta (gpointer element, GstBuffer * buf)
+{
+  gst_rtp_drop_meta (element, buf, rtp_quark_meta_tag_video);
+}
+
+/* Stolen from bad/gst/mpegtsdemux/payloader_parsers.c */
+/* variable length Exp-Golomb parsing according to H.265 spec section 9.2*/
+gboolean
+gst_rtp_read_golomb (GstBitReader * br, guint32 * value)
+{
+  guint8 b, leading_zeros = -1;
+  *value = 1;
+
+  for (b = 0; !b; leading_zeros++) {
+    if (!gst_bit_reader_get_bits_uint8 (br, &b, 1))
+      return FALSE;
+    *value *= 2;
+  }
+
+  *value = (*value >> 1) - 1;
+  if (leading_zeros > 0) {
+    guint32 tmp = 0;
+    if (!gst_bit_reader_get_bits_uint32 (br, &tmp, leading_zeros))
+      return FALSE;
+    *value += tmp;
+  }
+
+  return TRUE;
+}
